@@ -1,3 +1,3 @@
 from hungovercoders_template_python_package import hello
 
-print(hello())
\ No newline at end of file
+hello("griff")
\ No newline at end of file
